==> cscec5b-op-impl-3.0.0-20220922.021623-8-sources.jar: com/ejianc/business/op/bean/ApplyEntity.java <==
package com.ejianc.business.op.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

import com.ejianc.business.op.bean.ApplyDetailEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

/**
 * 申请实体
 *
 * @author generator
 *
 */
 @TableName("ejc_op_apply")
public class ApplyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="org_id")
    private Long orgId; // 组织主键
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 上级组织id
    @TableField(value="project_id")
    private Long projectId; // 项目主键
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="apply_dept")
    private String applyDept; // 申请单位
    @TableField(value="car_number")
    private String carNumber; // 车牌号
    @TableField(value="out_date")
    private Date outDate; // 出场日期
    @TableField(value="apply_user")
    private String applyUser; // 申请人
    @TableField(value="tel")
    private String tel; // 电话
    @TableField(value="op_status")
    private Integer opStatus; // 出门状态 0-暂存 1-提交 2-审批中 3-待核验 4-驳回 5-待确认 6-核验不通过  7-已出门 8-确认不通过
    @TableField(value="tpurl")
    private String tpurl; // 现场照片URL
    @TableField(value="qrcode")
    private String qrcode; // 二维码信息
    @TableField(value="check_note")
    private String checkNote; // 核验说明
    @TableField(value="hyurl")
    private String hyurl; // 核验照片URL
    @TableField(value="check_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date checkTime; // 核验时间
    @TableField(value="checker_open_id")
    private String checkerOpenId; // 核验人openid
    @TableField(value="checker_id")
    private Long checkerId; // 核验人ID
    @TableField(value="checker_name")
    private String checkerName; // 核验人姓名
    @TableField(value="confirm_note")
    private String confirmNote; // 确认说明
    @TableField(value="qrurl")
    private String qrurl; // 确认照片URL
    @TableField(value="confirm_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date confirmTime; // 确认时间
    @TableField(value="confirmer_id")
    private Long confirmerId; // 确认人ID
    @TableField(value="confirmer_open_id")
    private String confirmerOpenId; // 确认人openid
    @TableField(value="confirmer_name")
    private String confirmerName; // 确认人姓名
    @TableField(value="inside_flag")
    private Integer insideFlag; // 是否内部人员(0-否 1-是)
    @TableField(value="user_id")
    private Long userId; // 用户主键
    @TableField(value="guard_user_id")
    private Long guardUserId; // 门岗用户主键
    @TableField(value="open_id")
    private String openId; // openid
    @TableField(value="out_type")
    private Integer outType; // 出场类型(1-分包物资、2-租赁材退场、3-废旧物资处理、4-维修、5-调拨退场、6-其他)
    @TableField(value="branch_corp_id")
    private Long branchCorpId; // 所属公司主键
    @TableField(value="branch_corp_name")
    private String branchCorpName; // 所属公司名称


    @TableField(exist=false)
    @SubEntity(serviceName="applyDetailService")//此处有pid="xxx"，默认值pid="pid"
    private List<ApplyDetailEntity> applyDetailList = new ArrayList<>(); // 申请子实体


    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getApplyDept() {
        return applyDept;
    }

    public void setApplyDept(String applyDept) {
        this.applyDept = applyDept;
    }
    public String getCarNumber() {
        return carNumber;
    }

    public void setCarNumber(String carNumber) {
        this.carNumber = carNumber;
    }
    public Date getOutDate() {
        return outDate;
    }

    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }
    public String getApplyUser() {
        return applyUser;
    }

    public void setApplyUser(String applyUser) {
        this.applyUser = applyUser;
    }
    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }
    public Integer getOpStatus() {
        return opStatus;
    }

    public void setOpStatus(Integer opStatus) {
        this.opStatus = opStatus;
    }
    public String getTpurl() {
        return tpurl;
    }

    public void setTpurl(String tpurl) {
        this.tpurl = tpurl;
    }
    public String getQrcode() {
        return qrcode;
    }

    public void setQrcode(String qrcode) {
        this.qrcode = qrcode;
    }
    public String getCheckNote() {
        return checkNote;
    }

    public void setCheckNote(String checkNote) {
        this.checkNote = checkNote;
    }
    public String getHyurl() {
        return hyurl;
    }

    public void setHyurl(String hyurl) {
        this.hyurl = hyurl;
    }
    public Date getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(Date checkTime) {
        this.checkTime = checkTime;
    }
    public Long getCheckerId() {
        return checkerId;
    }

    public void setCheckerId(Long checkerId) {
        this.checkerId = checkerId;
    }
    public String getCheckerName() {
        return checkerName;
    }

    public void setCheckerName(String checkerName) {
        this.checkerName = checkerName;
    }
    public String getConfirmNote() {
        return confirmNote;
    }

    public void setConfirmNote(String confirmNote) {
        this.confirmNote = confirmNote;
    }
    public String getQrurl() {
        return qrurl;
    }

    public void setQrurl(String qrurl) {
        this.qrurl = qrurl;
    }
    public Date getConfirmTime() {
        return confirmTime;
    }

    public void setConfirmTime(Date confirmTime) {
        this.confirmTime = confirmTime;
    }
    public Long getConfirmerId() {
        return confirmerId;
    }

    public void setConfirmerId(Long confirmerId) {
        this.confirmerId = confirmerId;
    }
    public String getConfirmerName() {
        return confirmerName;
    }

    public void setConfirmerName(String confirmerName) {
        this.confirmerName = confirmerName;
    }
    public Integer getInsideFlag() {
        return insideFlag;
    }

    public void setInsideFlag(Integer insideFlag) {
        this.insideFlag = insideFlag;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public Long getGuardUserId() {
        return guardUserId;
    }

    public void setGuardUserId(Long guardUserId) {
        this.guardUserId = guardUserId;
    }
    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }
    public Integer getOutType() {
        return outType;
    }

    public void setOutType(Integer outType) {
        this.outType = outType;
    }
    public Long getBranchCorpId() {
        return branchCorpId;
    }

    public void setBranchCorpId(Long branchCorpId) {
        this.branchCorpId = branchCorpId;
    }
    public String getBranchCorpName() {
        return branchCorpName;
    }

    public void setBranchCorpName(String branchCorpName) {
        this.branchCorpName = branchCorpName;
    }

    public String getCheckerOpenId() {
        return checkerOpenId;
    }

    public void setCheckerOpenId(String checkerOpenId) {
        this.checkerOpenId = checkerOpenId;
    }

    public String getConfirmerOpenId() {
        return confirmerOpenId;
    }

    public void setConfirmerOpenId(String confirmerOpenId) {
        this.confirmerOpenId = confirmerOpenId;
    }

    public List<ApplyDetailEntity> getApplyDetailList() {
        return applyDetailList;
    }

    public void setApplyDetailList(List<ApplyDetailEntity> applyDetailList) {
        this.applyDetailList = applyDetailList;
    }
}

==> cscec5b-op-impl-3.0.0-20220923.064238-14-sources.jar: com/ejianc/business/op/bean/ApplyEntity.java <==
package com.ejianc.business.op.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;
import com.fasterxml.jackson.annotation.JsonFormat;

import java.util.ArrayList;
import java.util.Date;
import java.util.List;

/**
 * 申请实体
 *
 * @author generator
 *
 */
 @TableName("ejc_op_apply")
public class ApplyEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="bill_state")
    private Integer billState; // 单据状态（审批必须字段）
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="org_id")
    private Long orgId; // 组织主键
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="parent_org_id")
    private Long parentOrgId; // 上级组织id
    @TableField(value="project_id")
    private Long projectId; // 项目主键
    @TableField(value="project_name")
    private String projectName; // 项目名称
    @TableField(value="apply_dept")
    private String applyDept; // 申请单位
    @TableField(value="car_number")
    private String carNumber; // 车牌号
    @TableField(value="out_date")
    private Date outDate; // 出场日期
    @TableField(value="apply_user")
    private String applyUser; // 申请人
    @TableField(value="tel")
    private String tel; // 电话
    @TableField(value="op_status")
    private Integer opStatus; // 出门状态 0-暂存 1-提交 2-审批中 3-待核验 4-驳回 5-待确认 6-核验不通过  7-已出门 8-确认不通过
    @TableField(value="tpurl")
    private String tpurl; // 现场照片URL
    @TableField(value="qrcode")
    private String qrcode; // 二维码信息
    @TableField(value="check_note")
    private String checkNote; // 核验说明
    @TableField(value="hyurl")
    private String hyurl; // 核验照片URL
    @TableField(value="check_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date checkTime; // 核验时间
    @TableField(value="checker_open_id")
    private String checkerOpenId; // 核验人openid
    @TableField(value="checker_id")
    private Long checkerId; // 核验人ID
    @TableField(value="checker_name")
    private String checkerName; // 核验人姓名
    @TableField(value="confirm_note")
    private String confirmNote; // 确认说明
    @TableField(value="qrurl")
    private String qrurl; // 确认照片URL
    @TableField(value="confirm_time")
    @JsonFormat(pattern = "yyyy-MM-dd HH:mm:ss", timezone = "GMT+8")
    private Date confirmTime; // 确认时间
    @TableField(value="confirmer_id")
    private Long confirmerId; // 确认人ID
    @TableField(value="confirmer_open_id")
    private String confirmerOpenId; // 确认人openid
    @TableField(value="confirmer_name")
    private String confirmerName; // 确认人姓名
    @TableField(value="inside_flag")
    private Integer insideFlag; // 是否内部人员(0-否 1-是)
    @TableField(value="user_id")
    private Long userId; // 用户主键
    @TableField(value="guard_user_id")
    private Long guardUserId; // 门岗用户主键
    @TableField(value="open_id")
    private String openId; // openid
    @TableField(value="out_type")
    private Integer outType; // 出场类型(1-分包物资、2-租赁材退场、3-废旧物资处理、4-维修、5-调拨退场、6-其他)
    @TableField(value="branch_corp_id")
    private Long branchCorpId; // 所属公司主键
    @TableField(value="branch_corp_name")
    private String branchCorpName; // 所属公司名称


    @TableField(exist=false)
    @SubEntity(serviceName="applyDetailService" ,pidName = "applyId")//此处有pid="xxx"，默认值pid="pid"
    private List<ApplyDetailEntity> detailList = new ArrayList<>(); // 申请子实体


    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
    public String getApplyDept() {
        return applyDept;
    }

    public void setApplyDept(String applyDept) {
        this.applyDept = applyDept;
    }
    public String getCarNumber() {
        return carNumber;
    }

    public void setCarNumber(String carNumber) {
        this.carNumber = carNumber;
    }
    public Date getOutDate() {
        return outDate;
    }

    public void setOutDate(Date outDate) {
        this.outDate = outDate;
    }
    public String getApplyUser() {
        return applyUser;
    }

    public void setApplyUser(String applyUser) {
        this.applyUser = applyUser;
    }
    public String getTel() {
        return tel;
    }

    public void setTel(String tel) {
        this.tel = tel;
    }
    public Integer getOpStatus() {
        return opStatus;
    }

    public void setOpStatus(Integer opStatus) {
        this.opStatus = opStatus;
    }
    public String getTpurl() {
        return tpurl;
    }

    public void setTpurl(String tpurl) {
        this.tpurl = tpurl;
    }
    public String getQrcode() {
        return qrcode;
    }

    public void setQrcode(String qrcode) {
        this.qrcode = qrcode;
    }
    public String getCheckNote() {
        return checkNote;
    }

    public void setCheckNote(String checkNote) {
        this.checkNote = checkNote;
    }
    public String getHyurl() {
        return hyurl;
    }

    public void setHyurl(String hyurl) {
        this.hyurl = hyurl;
    }
    public Date getCheckTime() {
        return checkTime;
    }

    public void setCheckTime(Date checkTime) {
        this.checkTime = checkTime;
    }
    public Long getCheckerId() {
        return checkerId;
    }

    public void setCheckerId(Long checkerId) {
        this.checkerId = checkerId;
    }
    public String getCheckerName() {
        return checkerName;
    }

    public void setCheckerName(String checkerName) {
        this.checkerName = checkerName;
    }
    public String getConfirmNote() {
        return confirmNote;
    }

    public void setConfirmNote(String confirmNote) {
        this.confirmNote = confirmNote;
    }
    public String getQrurl() {
        return qrurl;
    }

    public void setQrurl(String qrurl) {
        this.qrurl = qrurl;
    }
    public Date getConfirmTime() {
        return confirmTime;
    }

    public void setConfirmTime(Date confirmTime) {
        this.confirmTime = confirmTime;
    }
    public Long getConfirmerId() {
        return confirmerId;
    }

    public void setConfirmerId(Long confirmerId) {
        this.confirmerId = confirmerId;
    }
    public String getConfirmerName() {
        return confirmerName;
    }

    public void setConfirmerName(String confirmerName) {
        this.confirmerName = confirmerName;
    }
    public Integer getInsideFlag() {
        return insideFlag;
    }

    public void setInsideFlag(Integer insideFlag) {
        this.insideFlag = insideFlag;
    }
    public Long getUserId() {
        return userId;
    }

    public void setUserId(Long userId) {
        this.userId = userId;
    }
    public Long getGuardUserId() {
        return guardUserId;
    }

    public void setGuardUserId(Long guardUserId) {
        this.guardUserId = guardUserId;
    }
    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }
    public Integer getOutType() {
        return outType;
    }

    public void setOutType(Integer outType) {
        this.outType = outType;
    }
    public Long getBranchCorpId() {
        return branchCorpId;
    }

    public void setBranchCorpId(Long branchCorpId) {
        this.branchCorpId = branchCorpId;
    }
    public String getBranchCorpName() {
        return branchCorpName;
    }

    public void setBranchCorpName(String branchCorpName) {
        this.branchCorpName = branchCorpName;
    }

    public String getCheckerOpenId() {
        return checkerOpenId;
    }

    public void setCheckerOpenId(String checkerOpenId) {
        this.checkerOpenId = checkerOpenId;
    }

    public String getConfirmerOpenId() {
        return confirmerOpenId;
    }

    public void setConfirmerOpenId(String confirmerOpenId) {
        this.confirmerOpenId = confirmerOpenId;
    }

    public List<ApplyDetailEntity> getDetailList() {
        return detailList;
    }

    public void setDetailList(List<ApplyDetailEntity> detailList) {
        this.detailList = detailList;
    }
}
